@@ -1,4 +1,3 @@
-from pathlib import Path
 from typing import List
 
 from pytestarch.importer.import_types import Import
@@ -9,17 +8,15 @@ class ImportFilter:
     External modules are all modules that are not submodules of the configured module to search for imports.
     """
 
-    def __init__(
-        self, exclude_external_libraries: bool, root_module_path: Path
-    ) -> None:
+    def __init__(self, exclude_external_libraries: bool, root_module_name: str) -> None:
         """
         Args:
             exclude_external_libraries: If True, external modules will be filtered out, otherwise this class implements a no-op.
-            root_module_path: path to the module that determines which modules are considered external. If a module
+            root_module_name: name of the module that determines which modules are considered external. If a module
                 is a submodule of this module, it is considered internal.
         """
         self._exclude_external_libraries = exclude_external_libraries
-        self._root_module_path = root_module_path
+        self._root_module_name = root_module_name
 
     def filter(self, imports: List[Import]) -> List[Import]:
         """According to the configuration, imports will be filtered.
@@ -37,6 +34,4 @@ class ImportFilter:
     def _is_internal_import(self, i: Import) -> bool:
         importee = i.importee()
 
-        top_level_module = self._root_module_path.name
-
-        return importee.startswith(top_level_module)
+        return importee.startswith(self._root_module_name)
